package com.ynet.life.search;

import java.sql.ResultSet;
import java.sql.SQLException;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;

/* loaded from: com_ynet_life_search.jar:com/ynet/life/search/PMSBankNoIndexBuilder.class */
public class PMSBankNoIndexBuilder extends AbstractDBIndexBuilder {
    private static final String SQL_BANK_NO = "SELECT PBN_BANKNO, PBN_BANKTYPE, PBN_BANKNAME, PBN_STT, PBN_CITYCODE, CIT_NAME, PIF_CODE, PIF_NAME, APR_SHOWMSG  FROM PUB_PMSBANKNO, PUB_PROVINCEINFO, PUB_CITYINFO, PUB_APPPAR WHERE PBN_CITYCODE=CIT_CODE   AND CIT_PROVINCE=PIF_CODE    AND PBN_BANKTYPE=APR_VALUE    AND APR_CODE='BANK_TYPE'   AND APR_LANGUAGE='zh_cn'";
    private static final String SQL_BANK_INDEX_FIELD = "SELECT PBN_BANKNO, PBN_BANKTYPE, PBN_BANKNAME, PBN_STT, PBN_CITYCODE, CIT_NAME, PIF_CODE, PIF_NAME, APR_SHOWMSG";

    public PMSBankNoIndexBuilder(String indexFolderFile) {
        super(indexFolderFile, SQL_BANK_NO, SQL_BANK_INDEX_FIELD);
    }

    @Override // com.ynet.life.search.AbstractDBIndexBuilder
    protected Document getDocument(ResultSet rs) throws SQLException {
        String bankNo = rs.getString("PBN_BANKNO");
        String bankType = rs.getString("PBN_BANKTYPE");
        String bankName = rs.getString("PBN_BANKNAME");
        String state = rs.getString("PBN_STT");
        String cityCode = rs.getString("PBN_CITYCODE");
        String cityName = rs.getString("CIT_NAME");
        String provCode = rs.getString("PIF_CODE");
        String provName = rs.getString("PIF_NAME");
        String bankHeadName = rs.getString("APR_SHOWMSG");
        String bankNo2 = bankNo == null ? "" : bankNo.trim();
        String fullContents = String.valueOf(bankHeadName) + provName + cityName + bankName;
        Document doc = new Document();
        doc.add(new Field("keyWord", bankNo2, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("fullContents", fullContents, Field.Store.YES, Field.Index.ANALYZED));
        doc.add(new Field("unionBankNo", bankNo2, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("bankType", bankType, Field.Store.YES, Field.Index.ANALYZED));
        doc.add(new Field("bankName", bankName, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("state", state, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("cityCode", cityCode, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("cityName", cityName, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("provinceCode", provCode, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("provinceName", provName, Field.Store.YES, Field.Index.NOT_ANALYZED));
        doc.add(new Field("bankHeadName", bankHeadName, Field.Store.YES, Field.Index.NOT_ANALYZED));
        return doc;
    }
}
